import numpy as np

from ._version import get_versions
__version__ = get_versions()['version']
del get_versions

_coord_info = dict()
_coord_info['box_altitude'] = dict(
    default=np.arange(25e1, 16e3, 5e2),
    prompt="x altitudes [m] (default: '250, 750, ..., 15725' OR 'linspace, 250, 15725, 32' OR 'arange, 250, 16000, 500')",
    units='m',
    long_name='box altitude',
    standard_name='altitude',
    positive='up',
    clear_sky=True,
    cloudy_sky=True,
    mandatory=True
)
_coord_info['surface_albedo'] = dict(
    default=np.array([0.00, 0.03, 0.06, 0.09, 0.12, 0.20, 0.30, 0.50, 0.75, 1.00]),
    prompt="Surface albedo [unitless] (default: '0, 0.03, 0.06, 0.09, 0.12, 0.20, 0.30, 0.50, 0.75, 1.00')",
    units='1',
    long_name='surface albedo',
    standard_name='surface_albedo',
    clear_sky=True,
    cloudy_sky=False,
    mandatory=False
)
_coord_info['surface_pressure'] = dict(
    default=np.array([6e4, 8e4, 9e4, 1e5]),
    prompt="Surface pressure [Pa] (default: '6e4, 8e4, 9e4, 1e5')",
    units='Pa',
    long_name='surface air pressure',
    standard_name='surface_air_pressure',
    clear_sky=True,
    cloudy_sky=True,
    mandatory=False
)
_coord_info['cloud_top_pressure'] = dict(
    default=np.array([2e4, 4e4, 6e4, 8e4, 9e4]),
    prompt="Pressure at cloud top [Pa] (default: '2e4, 4e4 6e4, 8e4, 9e4')",
    units='Pa',
    long_name='air pressure at cloud top',
    standard_name='air_pressure_at_cloud_top',
    clear_sky=False,
    cloudy_sky=True,
    mandatory=False
)
_coord_info['cloud_albedo'] = dict(
    default=0.8,
    prompt="Cloud albedo [unitsless] (default: '0.8')",
    units='1',
    long_name='albedo of cloud',
    standard_name='cloud_albedo',
    clear_sky=False,
    cloudy_sky=True,
    mandatory=False
)
_coord_info['solar_zenith'] = dict(
    default=np.array([0., 30., 50., 60., 65., 70., 73., 76., 78., 80.]),
    prompt="Solar zenith angle [deg] (default: '0, 30, 50, 60, 65, 70, 73, 76, 78, 80')",
    units='degree',
    long_name='solar zenith angle',
    standard_name='solar_zenith_angle',
    clear_sky=True,
    cloudy_sky=True,
    mandatory=False
)
_coord_info['viewing_zenith'] = dict(
    default=np.array([0., 30., 50., 60., 65., 70., 72.]),
    prompt="Viewing zenith angle [deg] (default: '0, 30, 50, 60, 65, 70, 72')",
    units='degree',
    long_name='line of sight zenith angle',
    standard_name='platform_zenith_angle',
    clear_sky=True,
    cloudy_sky=True,
    mandatory=False
)
_coord_info['azimuth_difference'] = dict(
    default=np.linspace(0., 180., 7),
    prompt="Difference between viewing and solar azimuth angles [deg] (default: '0, 30, ..., 180')",
    units='degree',
    long_name='azimuth angle difference',
    standard_name='angle_of_rotation_from_solar_azimuth_to_platform_azimuth',
    clear_sky=True,
    cloudy_sky=True,
    mandatory=False
)
